@@ -1,6 +1,18 @@
 CreateGrammar <-
-function(ruleDef, startSymb = 'expr') {
+function(ruleDef, startSymb = "<expr>") {
 
+  # if the ruledef is a file, read it
+  if (("connection" %in% class(ruleDef)) | is.character(ruleDef)) {
+    ruleDef = ReadBNFFile(ruleDef)
+  }
+
+  # trim brackets from the rule index
+  trim_brackets <- function (x) gsub("^<+|>+$", "", x)
+  for (i in seq_along(ruleDef)) {
+    ruleDef[[i]][[1]] = trim_brackets(ruleDef[[i]][[1]])
+  }
+
+  # extract information about the grammar
   ruleSizes = sapply(ruleDef, function(r) length(r[[2]]))
 
   ruleDefIndex = sapply(ruleDef, function(r) r[[1]])
